==> haskell-unix-time-0.4.17-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unix-time
version:              0.4.17
visibility:           public
id:                   unix-time-0.4.17-AlOVKMHoW7WQCEwFyWGac
key:                  unix-time-0.4.17-AlOVKMHoW7WQCEwFyWGac
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Unix time parser/formatter and utilities
description:          Fast parser\/formatter\/utilities for Unix time
category:             Data
abi:                  e982fc7004180849ea7113073aae7c8e
exposed:              True
exposed-modules:      Data.UnixTime
hidden-modules:
    Data.UnixTime.Conv Data.UnixTime.Diff Data.UnixTime.Types
    Data.UnixTime.Sys

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unix-time-0.4.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-time-0.4.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unix-time-0.4.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-time
hs-libraries:         HSunix-time-0.4.17-AlOVKMHoW7WQCEwFyWGac
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9

haddock-interfaces:   /usr/share/doc/haskell-unix-time/html/unix-time.haddock
haddock-html:         /usr/share/doc/haskell-unix-time/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unix-time-0.4.17-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unix-time
version:              0.4.17
visibility:           public
id:                   unix-time-0.4.17-4wr5211M0ug3NyI6WFhtWO
key:                  unix-time-0.4.17-4wr5211M0ug3NyI6WFhtWO
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Unix time parser/formatter and utilities
description:          Fast parser\/formatter\/utilities for Unix time
category:             Data
abi:                  9e19222ea8fffe0e0ead4c0faa494ecb
exposed:              True
exposed-modules:      Data.UnixTime
hidden-modules:
    Data.UnixTime.Conv Data.UnixTime.Diff Data.UnixTime.Types
    Data.UnixTime.Sys

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unix-time-0.4.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-time-0.4.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unix-time-0.4.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-time
hs-libraries:         HSunix-time-0.4.17-4wr5211M0ug3NyI6WFhtWO
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9

haddock-interfaces:   /usr/share/doc/haskell-unix-time/html/unix-time.haddock
haddock-html:         /usr/share/doc/haskell-unix-time/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
